initialize
initialize
BankDetailsDetails for available banks that support the API
new()Initialize a new API client
.openBankingClient$new( bankDetails = "default", version = "latest", timeOutSeconds = 15 )
bankDetailsoptional. Bank details list to use. When set to "default", the bank details will be taken from the below URL: https://github.com/OpenBankingUK/opendata-api-spec-compiled/blob/master/participant_store.json Otherwise, the user can provide a custom list of bank details.
versionoptional. Which version of the API to use. Defaults to "latest. When set to "latest", the version used will be the latest available for the selected bank and instrument. This information will be derived from the bank details table above. Alternatively, the user can supply a manually set version such as "v2.3"
timeOutSecondsoptional. Number of seconds before a request times out. Defaults to 15 seconds
Object of type OpenBankingClient with methods for querying the API
GetAvailableBanks()Get available banks that support the API
.openBankingClient$GetAvailableBanks()
character list. Names of available banks
GetAvailableInstruments()Get available instruments for the API
.openBankingClient$GetAvailableInstruments()
character list. Names of available instruments
GetRawData()Get raw data for a specified bank and instrument
.openBankingClient$GetRawData(bankName, instrument)
bankNamecharacter. Name of the bank to get data for. See GetAvailableBanks()
instrumentcharacter. Instrument to get data for. See GetAvailableInstruments()
list. Raw data for the requested bank and instrument